---
title: <span class="badge object-type-scalar"></span> PolishZloty
---
# <span class="badge object-type-scalar"></span> PolishZloty

Currency: Polish Złoty (PLN)

## Definition

```python
# Currency: Polish Złoty (PLN)
PolishZloty: typing.Literal["currencyPLN"] = "currencyPLN"
```
